@@ -185,9 +185,6 @@ static void about_item_callback(GtkWidget * button, gpointer data)
 }
 
 #if MAEMO_VERSION >= 5
-#include <gdk/gdkx.h>
-#include <X11/Xatom.h>
-
 /** Called for each of the play/restart/continue buttons */
 static void found_ogs_button_callback(GtkWidget *widget, gpointer data)
 {
@@ -197,24 +194,6 @@ static void found_ogs_button_callback(GtkWidget *widget, gpointer data)
 	gtk_box_set_child_packing(GTK_BOX(data), widget,
 		FALSE, FALSE, 0, GTK_PACK_START);
 }
-/** Converts the window into a stackable one */
-static void plugin_realized_callback(GtkWidget *widget, gpointer data)
-{
-	GdkDisplay *display;
-    Atom atom;
-    unsigned long val = 0;
-	GtkWidget* window = gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW);
-
-    /* Set additional property "_HILDON_STACKABLE_WINDOW", 
-    	to allow the WM to manage it as a stackable window. */
-    display = gdk_drawable_get_display(window->window);
-    atom = gdk_x11_get_xatom_by_name_for_display (display,
-    				"_HILDON_STACKABLE_WINDOW");
-    XChangeProperty(GDK_DISPLAY_XDISPLAY(display),
-    				 GDK_WINDOW_XID(window->window),
-    				 atom, XA_INTEGER, 32, PropModeReplace,
-                     (unsigned char *) &val, 1);
-}
 #endif
 
 static GtkWidget * load_plugin(void)
@@ -382,11 +361,6 @@ static GtkWidget * load_plugin(void)
 
 	set_rom(gconf_client_get_string(gcc, kGConfRomFile, NULL));
 
-#if MAEMO_VERSION == 5
-	g_signal_connect_after(G_OBJECT(parent), "realize",
-						G_CALLBACK(plugin_realized_callback), NULL);
-#endif
-
 	// Connect signals
 	g_signal_connect(G_OBJECT(select_rom_btn), "clicked",
 					G_CALLBACK(select_rom_callback), NULL);
